# -*- coding: utf-8 -*-
# Part of Odoo. See LICENSE file for full copyright and licensing details.
from collections import OrderedDict
from operator import itemgetter

from odoo import http, _
from odoo.addons.portal.controllers.portal import CustomerPortal, pager as portal_pager
from odoo.exceptions import AccessError, MissingError
from collections import OrderedDict
from odoo.http import request

from odoo.osv.expression import OR

class PortalPrime(CustomerPortal):

    def _prepare_home_portal_values(self, counters):
        values = super()._prepare_home_portal_values(counters)
        if 'my_tickets_count' in counters:

            #Determine which tickets the logged in user can see
            ticket_access = []
            
            #Can see own tickets
            ticket_access.append(http.request.env.user.partner_id.id)

            #If the logged in user is a department manager then add all the contacts in the department to the access list
            for dep in request.env['website.support.department.contact'].sudo().search([('user_id','=',http.request.env.user.id)]):
                for contact in dep.wsd_id.partner_ids:
                    ticket_access.append(contact.id)

            search_t = [('partner_id', 'in', ticket_access), ('partner_id','!=',False)]
                    
            my_tickets_count = request.env['website.support.ticket'].sudo().search_count(search_t)
            
            values['my_tickets_count'] = my_tickets_count
        return values

    @http.route(['/support/ticket/view', '/support/ticket/view/page/<int:page>'], type='http', auth="user", website=True)
    def support_ticket_view_list(self, page=1, sortby=None, filterby=None, search=None, search_in='all', **kw):
        """Displays a list of support tickets owned by the logged in user"""

        values = self._prepare_portal_layout_values()
        Ticket = request.env['website.support.ticket']
        
        #Determine which tickets the logged in user can see
        ticket_access = []
        
        #Can see own tickets
        ticket_access.append(http.request.env.user.partner_id.id)

        #If the logged in user is a department manager then add all the contacts in the department to the access list
        for dep in request.env['website.support.department.contact'].sudo().search([('user_id','=',http.request.env.user.id)]):
            for contact in dep.wsd_id.partner_ids:
                ticket_access.append(contact.id)

        searchbar_sortings = {
            'date': {'label': _('Date'), 'order': 'create_date desc'},
            'state': {'label': _('Status'), 'order': 'state'},
        }

        searchbar_filters = {
            'all': {'label': _('All'), 'domain': []},
            'open': {'label': _('Open'), 'domain': [('state','=','open')]},
            'in_progress': {'label': _('In progress'), 'domain': [('state','=','in_progress')]},
            'blocked': {'label': _('Blocked'), 'domain': [('state','=','blocked')]},
            'cancel': {'label': _('Canceled'), 'domain': [('state','=','cancel')]},
            'closed': {'label': _('Closed'), 'domain': [('state','=','closed')]},
        }

        domain = [('partner_id', 'in', ticket_access), ('partner_id','!=',False)]

        # default sort by order
        if not sortby:
            sortby = 'date'
        order = searchbar_sortings[sortby]['order']

        # default filter by value
        if not filterby:
            filterby = 'all'
        domain += searchbar_filters.get(filterby, searchbar_filters.get('all'))['domain']

        # count for pager
        my_tickets_count = Ticket.search_count(domain)

        # pager
        pager = portal_pager(
            url="/support/ticket/view",
            url_args={'sortby': sortby, 'filterby': filterby, 'search_in': search_in,'search': search},
            total=my_tickets_count,
            page=page,
            step=self._items_per_page
        )
        # content according to pager and archive selected
        support_tickets = Ticket.search(domain, order=order, limit=self._items_per_page, offset=pager['offset'])
        request.session['my_support_tickets_history'] = support_tickets.ids[:100]

        values.update({
            'support_tickets': support_tickets,
            'page_name': 'my_support_tickets',
            'pager': pager,
            'default_url': '/support/ticket/view',
            'searchbar_sortings': searchbar_sortings,
            'search_in': search_in,
            'sortby': sortby,
            'searchbar_filters': OrderedDict(sorted(searchbar_filters.items())),
            'filterby': filterby,
            'search': search,
        })
        return request.render('prime_helpdesk.support_ticket_view_list', values)
